summaryrefslogtreecommitdiffstats
path: root/kdat/TapeManager.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:25:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:25:18 +0000
commitaa3a1ca934bc541bddd3fa136a85f106f7da266e (patch)
tree9ad0b795aed8fa4ac30c2fe0fd1aacb8175714c0 /kdat/TapeManager.cpp
parentb10cf7066791a2f362495890cd50c984e8025412 (diff)
downloadtdeadmin-aa3a1ca934bc541bddd3fa136a85f106f7da266e.tar.gz
tdeadmin-aa3a1ca934bc541bddd3fa136a85f106f7da266e.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeadmin@1157635 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdat/TapeManager.cpp')
-rw-r--r--kdat/TapeManager.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/kdat/TapeManager.cpp b/kdat/TapeManager.cpp
index 5de218e..919872f 100644
--- a/kdat/TapeManager.cpp
+++ b/kdat/TapeManager.cpp
@@ -19,9 +19,9 @@
#include <stdlib.h>
#include <unistd.h>
-#include <qdir.h>
-#include <qregexp.h>
-#include <qfile.h>
+#include <tqdir.h>
+#include <tqregexp.h>
+#include <tqfile.h>
#include <kglobal.h>
#include <kstandarddirs.h>
@@ -36,20 +36,20 @@ TapeManager::TapeManager()
_tapes.setAutoDelete( TRUE );
// Get a list of all available tape indexes.
- QStringList relList;
+ TQStringList relList;
// Fix 2002-01-24 c/o RG. The problem was: "Tape Index is empty, but I did
// just a few minutes ago a 1st backup onto the the tape."
// (void) KGlobal::dirs()->findAllResources( "appdata", ".*:[0-9]+", false, true, relList);
(void) KGlobal::dirs()->findAllResources( "appdata", "*:[0-9]*", false, true, relList);
- for(QStringList::Iterator it = relList.begin();
+ for(TQStringList::Iterator it = relList.begin();
it != relList.end();
it++)
{
- QString fn = *it;
- // Convert to outdated QStringList :-)
- _tapeIDs.append( QFile::encodeName(fn) );
+ TQString fn = *it;
+ // Convert to outdated TQStringList :-)
+ _tapeIDs.append( TQFile::encodeName(fn) );
}
}
@@ -68,21 +68,21 @@ TapeManager* TapeManager::instance()
return _instance;
}
-const QStringList& TapeManager::getTapeIDs()
+const TQStringList& TapeManager::getTapeIDs()
{
return _tapeIDs;
}
-Tape* TapeManager::findTape( const QString & id )
+Tape* TapeManager::findTape( const TQString & id )
{
/* 2002-01-26 LEW */
// printf("Contents of _tapeIDs: %d entries\n", _tapes.count());
- // for ( QStringList::Iterator it = _tapeIDs.begin(); it != _tapeIDs.end(); ++it ) {
+ // for ( TQStringList::Iterator it = _tapeIDs.begin(); it != _tapeIDs.end(); ++it ) {
// printf("%s\n", (*it).latin1());
// }
// printf("\n");
- // QDictIterator<Tape> it( _tapes );
+ // TQDictIterator<Tape> it( _tapes );
// printf("Contents of _tapes: %d entries\n", _tapes.count());
// for( ; it.current(); ++it )
// printf("index ?: %s (%d)\n", it.current()->getName().latin1(),
@@ -118,9 +118,9 @@ void TapeManager::removeTape( Tape* tape )
emit sigTapeRemoved( tape );
// Remove the index file.
- QString filename = locateLocal( "appdata", tape->getID() );
+ TQString filename = locateLocal( "appdata", tape->getID() );
- unlink( QFile::encodeName(filename) );
+ unlink( TQFile::encodeName(filename) );
_tapeIDs.remove( tape->getID() );
_tapes.remove( tape->getID() );